@@ -40,11 +40,6 @@ volatile int global_lastsig;
 #define SWINSTALL_VOLATILE_SUFFIX	".swbisnew"
 #define SWREMOVE_VOLATILE_SUFFIX	".swbisold"
 
-#define SWC_SHELL_KEY_SH	"sh"
-#define SWC_SHELL_KEY_KSH	"ksh"
-#define SWC_SHELL_KEY_BASH	"bash"
-#define SWC_SHELL_KEY_POSIX	"posix"
-#define SWC_SHELL_KEY_DETECT	"detect"
 
 #define PAX_READ_COMMANDS_LEN	10
 #define PAX_WRITE_COMMANDS_LEN	10
@@ -60,13 +55,10 @@ volatile int global_lastsig;
 #define CMD_TAINTED_CHARS  "'|\"*?;&<>`$"
 #define SW_FAILED_ALL_TARGETS		1
 #define SW_FAILED_SOME_TARGETS		2
-#define SIGNER_PGP5_BIN			"pgps"
-#define SIGNER_PGP26_BIN		"pgp"
-#define SIGNER_GPG_BIN			"gpg"
-#define SIGNER_GPG2_BIN			"gpg2"
 
 #define SWBIS_TARGET_CTL_MSG_125 	"125 target script started"
 #define SWBIS_TARGET_CTL_MSG_128 	"128 catalog path determined"
+#define SWBIS_TARGET_CTL_MSG_129 	"129 current directory"
 #define SWBIS_TARGET_CTL_MSG_508 	"508 target script error"
 #define SWBIS_SOURCE_CTL_ARCHIVE	"130 source is from archive"
 #define SWBIS_SOURCE_CTL_DIRECTORY 	"140 source is from directory"
@@ -111,19 +103,22 @@ volatile int global_lastsig;
 #define SWBIS_TS_preview_task		"Preview Task"
 #define SWBIS_TS_make_live_INSTALLED	"Make INSTALLED status live"
 #define SWBIS_TS_make_locked_session	"Lock Session"
-#define SWBIS_TS_released_locked_session  "UnLock Session"
 #define SWBIS_TS_check_loop  		"Check Loop"
 #define SWBIS_TS_continue		"Programmed Continue"
 #define SWBIS_TS_report_status 		"Report Status"
 #define SWBIS_TS_remove_catalog_entry	"Remove catalog entry"
 #define SWBIS_TS_restore_catalog_entry	"Restore catalog entry"
 #define SWBIS_TS_remove_files		"Remove files"
-#define SWBIS_TS_retrieve_files_archive "Retrive files archive"
+#define SWBIS_TS_retrieve_files_archive "Retrieve files archive"
 #define SWBIS_TS_post_verify		"Run post Verify"
 #define SWBIS_TS_get_catalog_perms	"Get catalog permissions"
 #define SWBIS_TS_run_configure		"Run configure script"
 #define SWBIS_TS_Load_INSTALLED_transient  SWBIS_TS_Load_INSTALLED " transient"
 #define SWBIS_TS_Load_management_host_status "Load manangement host status"
+#define SWBIS_TS_check_OVERWRITE	"Check overwrites"
+#define SWBIS_TS_check_status		"Check Status"
+
+
 
 
 #define SWPARSE_AT_LEVEL	0
