@@ -2984,6 +2984,13 @@ write_target_install_script(GB * G,
 	"       sw_retval=$?\n"
 	"	case \"$opt_preview\" in \"\") ;; *) sw_retval=0;; esac\n"
 	"       swexec_status=$sw_retval\n"
+	
+	"	shls_bashin2 \"" SWBIS_TS_Do_nothing "\"\n"
+	"	sw_retval=$?\n"
+	"	case $sw_retval in 0) $sh_dash_s " SWBIS_TS_Do_nothing ";; *) shls_false_;; esac\n"
+	"	sw_retval=$?\n"
+	"	case \"$opt_preview\" in \"\") ;; *) sw_retval=0;; esac\n"
+	"	swexec_status=$sw_retval\n"
 
 	CSHID
 	"	shls_bashin2 \"" SWBIS_TS_Get_iscs_entry "\"\n"
@@ -2999,6 +3006,13 @@ write_target_install_script(GB * G,
 	"	sw_retval=$?\n"
 	"	case \"$opt_preview\" in \"\") ;; *) sw_retval=0;; esac\n"
 	"	swexec_status=$sw_retval\n"
+
+	"	shls_bashin2 \"" SWBIS_TS_Do_nothing "\"\n"
+	"	sw_retval=$?\n"
+	"	case $sw_retval in 0) $sh_dash_s " SWBIS_TS_Do_nothing ";; *) shls_false_;; esac\n"
+	"	sw_retval=$?\n"
+	"	case \"$opt_preview\" in \"\") ;; *) sw_retval=0;; esac\n"
+	"	swexec_status=$sw_retval\n"
 	
 	CSHID
 	"	shls_bashin2 \"" SWBIS_TS_remove_catalog_entry "\"\n"
