@@ -143,7 +143,6 @@ looper_locked_region(STROB * buf, int vlv)
 
 		"				read swspec_string\n"                  /* SWBIS_DT_0001 */
 		"				%s\n" /* SW_SELECTION_EXECUTION_BEGINS */
-
 		"				# echo Processing Now \"$catentdir\" 1>&2\n"
 		"				echo \"$catentdir\"\n"			/* SWBIS_DT_0002 */
 
@@ -171,7 +170,7 @@ looper_locked_region(STROB * buf, int vlv)
 		"				case $sw_retval in 0) $sh_dash_s;; *) shls_false_;; esac\n"
 		"				sw_retval=$?\n"
 		"				swexec_status=$sw_retval\n"
-
+		
 		"				case $swexec_status in\n"
 		"			"	xSTR(SWP_RP_STATUS_NO_GNU_TAR) ") swexec_status=0\n"
 		"				;;\n"
@@ -179,7 +178,7 @@ looper_locked_region(STROB * buf, int vlv)
 
 		"				shls_bashin2 \"" SWBIS_TS_Catalog_dir_remove "\"\n"
 		"				sw_retval=$?\n"
-		"				case $sw_retval in 0) $sh_dash_s;; *) shls_false_;; esac\n"
+		"				case $sw_retval in 0) $sh_dash_s;; *) sleep 2; shls_false_;; esac\n"
 		"				sw_retval=$?\n"
 		"				swexec_status=$sw_retval\n"
 
@@ -816,6 +815,12 @@ swlist_write_source_copy_script2(GB * G,
 		"sw_retval=$?\n"
 		"swexec_status=$sw_retval\n"
 
+		"shls_bashin2 \"" SWBIS_TS_Do_nothing "\"\n"
+		"sw_retval=$?\n"
+		"case $sw_retval in 0) $sh_dash_s " SWBIS_TS_Do_nothing ";; *) shls_false_;; esac\n"
+		"sw_retval=$?\n"
+		"swexec_status=$sw_retval\n"
+
 		"		case \"$pgm_mode\" in\n"
 		"		" SWLIST_PMODE_FILE "|" SWLIST_PMODE_INDEX "|" SWLIST_PMODE_ATT ")\n"	
 		"			shls_looper \"$sw_retval\"\n"
@@ -1180,6 +1185,7 @@ swlist_looper_sr_payload(GB * G, BLIST * BL, char * target_path, char * cl_targe
 	SWI_FILELIST * file_list;
 	SWGPG_VALIDATE * swgpg;
 	int archive_fd;
+	int no_permission = 0;
 	
 	archive_fd = -1;
 	do_skip_entry = 0;
@@ -1224,7 +1230,7 @@ swlist_looper_sr_payload(GB * G, BLIST * BL, char * target_path, char * cl_targe
 	/* fprintf(stderr, "ENTRY: [%s]\n", catalog_entry_directory); */
 
 	strob_sprintf(btmp, 0, "%s\n", catalog_entry_directory);
-	E_DEBUG2("servicing looper: writing: [%s]", strob_str(btmp));
+	E_DEBUG2("servicing looper: writing for shls_looper_payload arg0: [%s]", strob_str(btmp));
 
 	/* write the catalog entry directory which becomes arg1 to
 	   the shls_looper_payload() routine */
@@ -1254,7 +1260,9 @@ swlist_looper_sr_payload(GB * G, BLIST * BL, char * target_path, char * cl_targe
 	if (ret != 0) {
 		sw_e_msg(G, "error from swpl_send_success()\n");
 		E_DEBUG("error");
-		return -2;
+		rstatus = 1;
+		retval = -1;  /* protocol internal error */
+		goto error_out;
 	}
 
 	/* Make a session lock */
@@ -1271,15 +1279,17 @@ swlist_looper_sr_payload(GB * G, BLIST * BL, char * target_path, char * cl_targe
 		E_DEBUG2("error ret=%d", ret);
 		sw_d_msg(G, "swpl_session_lock: lock fail for %s, ret=%d\n", strob_str(btmp), ret);
 		sw_e_msg(G, "error from swpl_session_lock: status=%d\n", ret);
-		return -4;
+		rstatus = 1;
+		retval = -4;
+		goto error_out;
 	} else if (ret > 0) {
 		/* session in progress, or no access to make lock */
 		E_DEBUG2("error ret=%d", ret);
 		sw_e_msg(G, "swpl_session_lock lock failed for %s, ret=%d\n", strob_str(btmp), ret);
 		/* sw_d_msg(G, "swpl_session_lock lock failed for %s, ret=%d\n", strob_str(btmp), ret); */
-		/* *p_rp_status = SWP_RP_STATUS_NO_LOCK; */
-		*p_rp_status = 1;
-		return 1;
+		rstatus = SWP_RP_STATUS_NO_LOCK;
+		retval = 1;
+		goto error_out;
 	} 
 
 	/*
@@ -1322,10 +1332,10 @@ swlist_looper_sr_payload(GB * G, BLIST * BL, char * target_path, char * cl_targe
 
 	E_DEBUG("");
 	ret = swicat_e_open_entry_tarball(ee, ifd);
-	if (ret < 0) {
+	if (ret != 0) {
 		sw_e_msg(G, "error opening catalog entry tarball, ret=%d\n", ret);
 		rstatus = 1;
-		retval = -1;  /* protocol internal error */
+		retval = -2;  /* protocol internal error */
 		looper_abort(G, swicol, ofd);
 		goto error_out;
 	}
@@ -1353,7 +1363,7 @@ swlist_looper_sr_payload(GB * G, BLIST * BL, char * target_path, char * cl_targe
 	ret = swicat_e_reset_fd(ee);
 	if (ret < 0) {
 		rstatus = 2;
-		retval = -1;
+		retval = -3;
 		sw_e_msg(G, "error reseting swicat_e object, ret=%d\n", ret);
 		looper_abort(G, swicol, ofd);
 		goto error_out;
@@ -1426,6 +1436,7 @@ swlist_looper_sr_payload(GB * G, BLIST * BL, char * target_path, char * cl_targe
 		/* swi might be NULL due to file system permission,
 		   handle NULL gracefully */
 		do_skip_entry = 1;
+		no_permission = SWP_RP_STATUS_NO_PERMISSION;
 		sw_e_msg(G, "catalog read error, possible permission denied: %s/%s\n", target_path, epath);
 	} else {
 		swi->verboseM = G->g_verboseG;
@@ -1452,13 +1463,11 @@ swlist_looper_sr_payload(GB * G, BLIST * BL, char * target_path, char * cl_targe
 	
 	E_DEBUG2("LOWEST FD=%d", show_nopen());
 	ret = swpl_report_status(swicol, ofd, G->g_swi_event_fd);
-	*p_rp_status = ret;
-	E_DEBUG2("setting *p_rp_status = %d", ret);
 	if (ret) {
-		/* looper_abort(G, swicol, ofd); */
+		E_DEBUG("error at TS_report_status");
 		rstatus = 6;
-		retval = 0;
-		do_skip_entry = 1;
+		retval = -4;
+		goto error_out;
 	}
 	if (G->g_do_debug_events)
 		swicol_show_events_to_fd(swicol, STDERR_FILENO, -1);
@@ -1467,10 +1476,11 @@ swlist_looper_sr_payload(GB * G, BLIST * BL, char * target_path, char * cl_targe
 
 	E_DEBUG2("LOWEST FD=%d", show_nopen());
 	ret = swicol_rpsh_wait_cts(swicol, G->g_swi_event_fd);
-	*p_rp_status = ret;
-	E_DEBUG2("setting *p_rp_status = %d", ret);
 	if (ret) {
-		looper_abort(G, swicol, ofd);
+		E_DEBUG("error");
+		rstatus = -1;
+		retval = -5;
+		goto error_out;
 	}
 
 	if (G->g_do_debug_events)
@@ -1482,18 +1492,16 @@ swlist_looper_sr_payload(GB * G, BLIST * BL, char * target_path, char * cl_targe
 	if (swi) { 
 		file_list = swicat_e_make_file_list(ee, uts, swi);
 	} else {
+		E_DEBUG("file_list is NULL");
 		file_list = NULL;
 	}
 	E_DEBUG2("LOWEST FD=%d", show_nopen());
 
 	if (swi && file_list == NULL) {
+		E_DEBUG("file_list is NULL");
 		rstatus = 7;
 		retval = 0;
 		do_skip_entry = 1;
-		/* 
-		looper_abort(G, swicol, ofd);
-		goto error_out;
-		*/
 	}
 	
 	if (
@@ -1518,25 +1526,29 @@ swlist_looper_sr_payload(GB * G, BLIST * BL, char * target_path, char * cl_targe
 		do_skip_entry ||
 		0
 	) {
+		E_DEBUG("skipping at swpl_unpack_catalog_tarfile");
 		ret = swpl_send_nothing_and_wait(swicol, ofd, G->g_swi_event_fd,
 			SWBIS_TS_Catalog_unpack,
 			SWICOL_TL_8,
 			SW_SUCCESS);
 		if (ret != 0) {
-			looper_abort(G, swicol, ofd);
+			E_DEBUG("");
+			rstatus = -2;
+			retval = -8;
 			goto error_out;
-			retval = -1;
 		}
 	} else {
+		E_DEBUG("at swpl_unpack_catalog_tarfile");
 		ret = swpl_unpack_catalog_tarfile(G, swi, ofd,
 			catalog_entry_directory,
 			pax_read_command,
 			0 /*alt_catalog_root*/,
 			G->g_swi_event_fd);
 		if (ret != 0) {
-			looper_abort(G, swicol, ofd);
+			E_DEBUG("error in swpl_unpack_catalog_tarfile");
+			rstatus = -3;
+			retval = -9;
 			goto error_out;
-			retval = -1;
 		}
 	}
 
@@ -1556,9 +1568,10 @@ swlist_looper_sr_payload(GB * G, BLIST * BL, char * target_path, char * cl_targe
 			SWICOL_TL_8,
 			SW_SUCCESS);
 		if (ret != 0) {
-			looper_abort(G, swicol, ofd);
+			E_DEBUG("");
+			rstatus = -4;
+			retval = -10;
 			goto error_out;
-			retval = -1;
 		}
 	} else {
 		E_DEBUG("running swpl_retrieve_files");
@@ -1587,9 +1600,9 @@ swlist_looper_sr_payload(GB * G, BLIST * BL, char * target_path, char * cl_targe
 		E_DEBUG2("LOWEST FD=%d", show_nopen());
 		E_DEBUG("");
 		if (ret < 0) {
+			E_DEBUG("");
 			rstatus = 8;
-			retval = -1;
-			looper_abort(G, swicol, ofd);
+			retval = -11;
 			goto error_out;
 		} else if (ret > 0) {
 			if (ret == SWP_RP_STATUS_NO_GNU_TAR) {
@@ -1667,9 +1680,8 @@ swlist_looper_sr_payload(GB * G, BLIST * BL, char * target_path, char * cl_targe
 			SW_SUCCESS);
 		if (ret != 0) {
 			E_DEBUG("swpl_send_nothing_and_wait(SWBIS_TS_Catalog_dir_remove) returned error");
-			looper_abort(G, swicol, ofd);
+			retval = -12;
 			goto error_out;
-			retval = -1;
 		}
         } else {
 		E_DEBUG("Remove catalog dir");
@@ -1681,9 +1693,8 @@ swlist_looper_sr_payload(GB * G, BLIST * BL, char * target_path, char * cl_targe
 			G->g_swi_event_fd);
 		if (ret != 0) {
 			E_DEBUG("swpl_remove_catalog_directory returned error");
-			looper_abort(G, swicol, ofd);
+			retval = -13;
 			goto error_out;
-			retval = -1;
 		}
 	}
 
@@ -1706,6 +1717,8 @@ swlist_looper_sr_payload(GB * G, BLIST * BL, char * target_path, char * cl_targe
 		*p_rp_status = rstatus;
 		E_DEBUG2("setting *p_rp_status = %d", rstatus);
 	}
+	if (no_permission)
+		*p_rp_status = no_permission;
 	if (swi) swi_delete(swi);
 	if (swgpg) swgpg_delete(swgpg);
 	if (ee) swicat_e_delete(ee);
