@@ -2119,7 +2119,7 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 			ret = 0;
 			if (f_retval == 0)
 				ret = swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
-						SWBIS_TS_Do_nothing ": testing 123");
+						SWBIS_TS_Do_nothing ": guarding 123");
 			if (ret != 0) {
 				abort_script(swicol, G, target_fdar[1]);
         			swpl_send_abort(swicol, target_fdar[1], G->g_swi_event_fd, "");
@@ -2143,6 +2143,10 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 				raise(SIGINT);
 				response_img = NULL;
 			}
+				
+			if (f_retval == 0)
+				swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
+					SWBIS_TS_Do_nothing ": guarding 1234");
 
 			E_DEBUG("");
 
@@ -2286,10 +2290,12 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 
 			E_DEBUG("");
 			ret = 0;
-			if (f_retval == 0)
+			if (1 || f_retval == 0) {
+				/* this always should be run */
 				ret = swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
-						SWBIS_TS_Do_nothing ": testing 89");
+						SWBIS_TS_Do_nothing ": guarding 89");
 
+			}
 			E_DEBUG("");
 			if (ret != 0) {
 				abort_script(swicol, G, target_fdar[1]);
@@ -2396,11 +2402,11 @@ ENTER_WITH_FAILURE2:
 				G->g_verboseG);
 		}
 		E_DEBUG("");
-		swlib_wait_on_all_pids(
+		swlib_wait_on_all_pids_with_timeout(
 				G->g_pid_array, 
 				G->g_pid_array_len, 
-				G->g_status_array, 0 /*waitpid flags*/, 
-				G->g_verboseG - 2);
+				G->g_status_array, WNOHANG /*waitpid flags*/, 
+				G->g_verboseG - 2, -3);
 
 		E_DEBUG("");
 
