@@ -25,7 +25,7 @@
 #include "swdeffileset.h"
 
 swDefFileset::swDefFileset (void): swDefinition() { }
-swDefFileset::swDefFileset (int level): swDefinition("fileset", level) { }
+swDefFileset::swDefFileset (int level): swDefinition(SW_A_fileset, level) { }
 
 swDefFileset::~swDefFileset (void){ 
 }
