@@ -1005,11 +1005,11 @@ rpmpsf_write_fileset(TOPSF * topsf, int uxfio_ofd, char *fileset_tag, char * fil
 			if (topsf->use_recursive_ == 0) {
 				ret += rpmpsf_write_psf_files(topsf, uxfio_ofd, -1, source_prefix, strb1);
 			} else {
-				int nullfd = open("/dev/null", O_RDWR, 0);
+				int nullfd = swbis_devnull_open("/dev/null", O_RDWR, 0);
 				strob_strcpy(strb1, "directory .\nfile *\n");
 				uxfio_write(uxfio_ofd, (void*)strob_str(strb1), strob_strlen(strb1));
 				ret += rpmpsf_write_psf_files(topsf, nullfd, -1, source_prefix, strb1);
-				close(nullfd);
+				swbis_devnull_close(nullfd);
 			}
 			if (ret) { SWBIS_ERROR_IMPL(); }
 		}
@@ -1464,7 +1464,6 @@ rpmpsf_write_file_psf(TOPSF * topsf, int arrayindex, int uxfio_ofd, char *source
 	ret += rpmpsf_get_rpmtagvalue(h, RPMTAG_FILEMTIMES, arrayindex, (int *) NULL, strb);
 	rpmpsf_write_rpm_attribute("mtime", strob_str(strb), -1, -1, h, NULL, uxfio_ofd);
 
-
 	ret += rpmpsf_get_rpmtagvalue(h, RPMTAG_FILEMODES, arrayindex, (int *) NULL, strb);
 	mode = (mode_t) swlib_atoi(strob_str(strb), NULL);
 	modeval[0] = (char) get_filetype(topsf, path, mode, &link_s);
@@ -1928,13 +1927,11 @@ rpmpsf_get_rpm_filenames_tagvalue(Header h, int index, int *pcount, STROB * strb
 		strob_strcat(strb, basename);
 		while ((p1 = strstr(strob_str(strb), "//")) != (char *) (NULL))
 			memmove(p1, p1 + 1, strlen(p1));
-		/* fprintf(stderr, "JL STRB = [%s]\n", strob_str(strb)); */
 	}
 	return 0;
 #else
 	int ret;
 	ret = rpmpsf_get_rpmtagvalue(h, RPMTAG_FILENAMES, index, pcount, strb);
-	/* fprintf(stderr, "JL STRB = [%s]\n", strob_str(strb)); */
 	return ret;
 #endif
 }
