@@ -259,9 +259,9 @@ int
 plain_source_tarball_write_psf_buf(TOPSF * topsf, STROB * psf)
 {
 	unsigned long int prefix_mode;
+	unsigned long ul_dir_mtime;
 	time_t dir_mtime;
 	int ret;
-	XFORMAT * data_xformat;
 	STROB * tmp;
 	STROB * xtmp;
 	STROB * desc;
@@ -270,11 +270,7 @@ plain_source_tarball_write_psf_buf(TOPSF * topsf, STROB * psf)
 	STRAR * name_fields;
 	XFORMAT * xformat;
 	AHS * ahs;
-	struct stat st;
 	char * name;
-	char * version;
-	char * arch;
-	char * build_num;
 
 	dir_mtime = (time_t)0;
 	name_fields = strar_open();
@@ -299,9 +295,10 @@ plain_source_tarball_write_psf_buf(TOPSF * topsf, STROB * psf)
 		/* this is a tar header, use it to set the <distribution>.mode
 		   attribute which set the mode of the leading path prefix. */
 		struct tar_header *tar_hdr;
-		tar_hdr = topsf->format_desc_->slackheaderM;
+		tar_hdr = (struct tar_header *)(topsf->format_desc_->slackheaderM);
 		taru_otoul(tar_hdr->mode, &prefix_mode);
-		taru_otoul(tar_hdr->mtime, &dir_mtime);
+		taru_otoul(tar_hdr->mtime, &ul_dir_mtime);
+		dir_mtime = (time_t)ul_dir_mtime;
 	} else {
 		prefix_mode = 0;
 	}
@@ -413,7 +410,6 @@ int
 slack_write_psf_buf(TOPSF * topsf, STROB * psf)
 {
 	int ret;
-	XFORMAT * data_xformat;
 	STROB * tmp;
 	STROB * xtmp;
 	STROB * desc;
@@ -428,9 +424,6 @@ slack_write_psf_buf(TOPSF * topsf, STROB * psf)
 	struct stat st;
 	char * sb;
 	char * name;
-	char * version;
-	char * arch;
-	char * build_num;
 
 	slack_desc = NULL;
 	doinst = NULL;
@@ -777,7 +770,6 @@ topsf_i_package_open(TOPSF * topsf, int oflags) {
 	int rc, isSource;
 	STROB * tagval = strob_open(12);
 	int tagret = -1;
-	int deb_data_fd;
 	int ret;
 
 	E_DEBUG("FUNCTION ENTER");
