@@ -114,12 +114,9 @@ static
 int
 compress_func(STROB * convline, STROB * plain_text, unsigned char ** cloc, int ** clen)
 {
-	int len;
-	char * buf;
 	int r;
 	lzo_uint in_len;
 	lzo_uint out_len;
-	lzo_uint new_len;
 	int IN_LEN = strob_strlen(plain_text) + 100;
 	int OUT_LEN = (IN_LEN + IN_LEN / 64 + 16 + 3);
 	lzo_byte * inbuf = malloc(IN_LEN);
@@ -294,7 +291,6 @@ main (int argc, char ** argv ) {
 	int uncompressed_len = 0;
 	FILE * flp;
 	STROB * function_name = strob_open(10);
-	STROB * var_name = strob_open(10);
 	STROB * convline = strob_open(10);
 	STROB * shell_function = strob_open(10);
 	STROB * text = strob_open(10);
