@@ -1,4 +1,4 @@
-/*  otar.c - read in write tar headers for cpio
+/*  otar.c - read and write tar headers
  */
    
 /*
@@ -86,6 +86,7 @@ static SYSDBPAIR userCacheM[CACHE_LEN];
 static SYSDBPAIR groupCacheM[CACHE_LEN];
 
 #include "debug_config.h"
+/*
 #define TARNEEDDEBUG 1
 #undef TARNEEDDEBUG
 
@@ -97,7 +98,8 @@ static SYSDBPAIR groupCacheM[CACHE_LEN];
 #define TAR_E_DEBUG(arg)
 #define TAR_E_DEBUG2(arg, arg1)
 #define TAR_E_DEBUG3(arg, arg1, arg2)
-#endif /* TARNEEDDEBUG */
+#endif
+*/
 
 static size_t
 split_long_name (const char *name, size_t length)
@@ -122,11 +124,11 @@ error_msg_control(char * name, int id, char * dbname)
 	if (store == NULL) store = strob_open(80);
 
 	if (name) {
-		strob_sprintf(tmp, 0, "%s: %s name [%s] not found in system database.\n",
+		strob_sprintf(tmp, 0, "%s: %s name [%s] not found in system db\n",
 					 swlib_utilname_get(), dbname, name);
 	} else {
 		strob_sprintf(tmp, 0,
-			"%s: %s id [%d] not found in system database.\n",
+			"%s: %s id [%d] not found in system db\n",
 				swlib_utilname_get(), dbname, (int)(id));
 	}
 	if (strstr(strob_str(store), strob_str(tmp))) {
@@ -354,7 +356,7 @@ get_pwent(
 			/*
 			 * Not found
 			 */
-			strncpy(buf, "nobody", 10);
+			strncpy(buf, AHS_USERNAME_NOBODY, 10);
 			dbcache_set(dbpair_len, cache, buf, id, -1);
 			error_msg_control((char*)NULL, id, g_pwent_msg[idx]);
 			return -1;
@@ -377,7 +379,7 @@ taru_get_uid_by_name(char *username, uid_t *puid)
 {
 	long pid;
 	int ret;
-	TAR_E_DEBUG("");
+	E_DEBUG("");
 	ret = get_pwent(0, 0, username, NULL,
 			&pid, 
 			l_getuidbyname, 
@@ -393,7 +395,7 @@ int
 taru_get_user_by_uid(uid_t uid, char * buf)
 {
 	int ret;
-	TAR_E_DEBUG("");
+	E_DEBUG("");
 	ret = get_pwent(0, uid, NULL, buf, NULL,
 			l_getuidbyname, 
 			l_tar_idcache_getuser,
@@ -408,7 +410,7 @@ taru_get_gid_by_name(char *groupname, gid_t *guid)
 {
 	int ret;
 	long pid;
-	TAR_E_DEBUG("");
+	E_DEBUG("");
 	ret =  get_pwent(1, 0, groupname, NULL,
 			&pid,
 			l_getgidbyname, 
@@ -424,7 +426,7 @@ int
 taru_get_group_by_gid(gid_t gid, char * buf)
 {
 	int ret;
-	TAR_E_DEBUG("");
+	E_DEBUG("");
 	ret = get_pwent(1, gid, NULL, buf, NULL,
 			l_getgidbyname, 
 			l_tar_idcache_getgroup,
@@ -1006,10 +1008,11 @@ taru_write_out_tar_header2(TARU * taru, struct new_cpio_header *file_hdr,
 		return -1;
 	}
 	
-	TAR_E_DEBUG2("ENTERING %d", out_des);
-	TAR_E_DEBUG3("ENTERING username = %s groupname = %s",\
-						username, groupname);
-	/* TAR_E_DEBUG2("file_hdr %s\n", taru_header_dump_string_s(file_hdr, "")); */
+	E_DEBUG3("ENTERING fd=%d, name=[%s]", out_des, ahsStaticGetTarFilename(file_hdr));
+	E_DEBUG3("username=[%s] groupname=[%s]", username, groupname);
+	E_DEBUG3("file_hdr: uid=[%d] gid=[%d]", (int)(file_hdr->c_uid), (int)(file_hdr->c_gid));
+
+
 	bzero((char *) &tar_rec, TARRECORDSIZE);
 
 	tar_iflags_like_star = (tar_iflags & TARU_TAR_BE_LIKE_STAR);
@@ -1018,6 +1021,7 @@ taru_write_out_tar_header2(TARU * taru, struct new_cpio_header *file_hdr,
 	tar_iflags_like_gnu = (tar_iflags & TARU_TAR_GNU_GNUTAR);
 	tar_iflags_like_oldgnu = (tar_iflags & TARU_TAR_GNU_OLDGNUTAR);
 	tar_iflags_like_oldgnuposix = (tar_iflags & TARU_TAR_GNU_OLDGNUPOSIX);
+	E_DEBUG2("tar_iflags_numeric_uids is %d", tar_iflags_numeric_uids);
 	
 	do_record_header = taru->do_record_headerM;
 
@@ -1100,7 +1104,7 @@ taru_write_out_tar_header2(TARU * taru, struct new_cpio_header *file_hdr,
 				fprintf(stderr,
 					"%s, link name [%s] too long for tar.\n",
 						swlib_utilname_get(), tmpp);
-				TAR_E_DEBUG("LEAVING");
+				E_DEBUG("LEAVING");
 				return -4;
 			}
 			strncpy(tar_hdr->linkname, tmpp, TARLINKNAMESIZE);
@@ -1135,7 +1139,7 @@ taru_write_out_tar_header2(TARU * taru, struct new_cpio_header *file_hdr,
 		if (strlen(tmpp) > TARLINKNAMESIZE) {
 			fprintf(stderr, "%s: link name [%s] too long for tar.\n",
 					swlib_utilname_get(), tmpp);
-			TAR_E_DEBUG("LEAVING");
+			E_DEBUG("LEAVING");
 			return -5;
 		}
 		strncpy(tar_hdr->linkname, tmpp, TARLINKNAMESIZE);
@@ -1173,7 +1177,7 @@ taru_write_out_tar_header2(TARU * taru, struct new_cpio_header *file_hdr,
 
 	if ((username == NULL || strlen(username) == 0) &&
 				file_hdr->c_cu != TARU_C_BY_UNONE) {
-		TAR_E_DEBUG("username nil");
+		E_DEBUG("username nil");
 		l_tar_idcache_getuser(file_hdr->c_uid, u_ent_buffer);
 		strncpy(tar_hdr->uname, u_ent_buffer, SNAME_LEN);
 	} else {
@@ -1183,9 +1187,10 @@ taru_write_out_tar_header2(TARU * taru, struct new_cpio_header *file_hdr,
 			file_hdr->c_cu == TARU_C_BY_UNAME
 			) 
 			{
-			TAR_E_DEBUG2("finding uid for username = %s", username);
+			E_DEBUG2("finding uid for username = %s", username);
 			if (taru_get_uid_by_name(username, &puid)) {
 				puid = NOBODY_ID;
+				E_DEBUG3("user name [%s] not found setting uid to %d", username, (int)puid);
 			}
 			swlib_strncpy(tar_hdr->uname, username, SNAME_LEN);
 		} else if (
@@ -1193,11 +1198,15 @@ taru_write_out_tar_header2(TARU * taru, struct new_cpio_header *file_hdr,
 			) 
 			{
 			puid = file_hdr->c_uid;
-			TAR_E_DEBUG2("finding user for uid  %d", (int)puid);
-			taru_get_user_by_uid(puid, u_ent_buffer);
-			swlib_strncpy(tar_hdr->uname, u_ent_buffer, SNAME_LEN);
+			E_DEBUG2("finding user for uid  %d", (int)puid);
+			if (tar_iflags_numeric_uids == 0) {
+				taru_get_user_by_uid(puid, u_ent_buffer);
+				swlib_strncpy(tar_hdr->uname, u_ent_buffer, SNAME_LEN);
+			} else {
+				swlib_strncpy(tar_hdr->uname, "", SNAME_LEN);
+			}
 		} else {
-			TAR_E_DEBUG("Using user and uid with no lookups");
+			E_DEBUG("Using user and uid with no lookups");
 			puid = file_hdr->c_uid;
 			swlib_strncpy(tar_hdr->uname, username, SNAME_LEN);
 		}	
@@ -1206,7 +1215,7 @@ taru_write_out_tar_header2(TARU * taru, struct new_cpio_header *file_hdr,
 
 	if ((groupname == NULL || strlen(groupname) == 0)
 				&& file_hdr->c_cg != TARU_C_BY_GNONE) {
-		TAR_E_DEBUG("groupname nil");
+		E_DEBUG("groupname nil");
 		l_tar_idcache_getgroup(file_hdr->c_gid, u_ent_buffer);
 		strncpy(tar_hdr->gname, u_ent_buffer, SNAME_LEN);
 	} else {
@@ -1217,21 +1226,26 @@ taru_write_out_tar_header2(TARU * taru, struct new_cpio_header *file_hdr,
 			file_hdr->c_cg == TARU_C_BY_GNAME
 			) 
 			{
-			TAR_E_DEBUG2("finding gid for groupname=%s", groupname);
+			E_DEBUG2("finding gid for groupname=%s", groupname);
 			swlib_strncpy(tar_hdr->gname, groupname, SNAME_LEN);
 			if (taru_get_gid_by_name(groupname, &pgid)) {
 				pgid = NOBODY_ID;
+				E_DEBUG3("group name [%s] not found setting uid to %d", groupname, (int)pgid);
 			}
 		} else if (
 			file_hdr->c_cg == TARU_C_BY_GID
 			) 
 			{
 			pgid = file_hdr->c_gid;
-			TAR_E_DEBUG2("finding gname for gid  %d", (int)pgid);
-			taru_get_group_by_gid(pgid, u_ent_buffer);
-			swlib_strncpy(tar_hdr->gname, u_ent_buffer, SNAME_LEN);
+			E_DEBUG2("finding gname for gid  %d", (int)pgid);
+			if (tar_iflags_numeric_uids == 0) {
+				taru_get_group_by_gid(pgid, u_ent_buffer);
+				swlib_strncpy(tar_hdr->gname, u_ent_buffer, SNAME_LEN);
+			} else {
+				swlib_strncpy(tar_hdr->gname, "", SNAME_LEN);
+			}
 		} else {
-			TAR_E_DEBUG("Using user and gid with no lookups");
+			E_DEBUG("Using user and gid with no lookups");
 			pgid = file_hdr->c_gid;
 			swlib_strncpy(tar_hdr->gname, groupname, SNAME_LEN);
 		}	
@@ -1290,7 +1304,7 @@ taru_write_out_tar_header2(TARU * taru, struct new_cpio_header *file_hdr,
 			taru->header_lengthM = TARRECORDSIZE;
 		}
 		memcpy(header_buffer, (void *) &tar_rec, 512);
-		TAR_E_DEBUG("LEAVING");
+		E_DEBUG("LEAVING");
 		return 512;
 	} else {
 		if (do_record_header) {
@@ -1299,7 +1313,7 @@ taru_write_out_tar_header2(TARU * taru, struct new_cpio_header *file_hdr,
 			taru->header_lengthM = TARRECORDSIZE;
 		}
 		ret = taru_safewrite(out_des, (void *) &tar_rec, TARRECORDSIZE);
-		TAR_E_DEBUG("LEAVING");
+		E_DEBUG("LEAVING");
 		return ret;
 	}
 }
