@@ -476,7 +476,7 @@ read_catalog_section(void * vp, int ifd)
 	int header_bytes;
 
 	E_DEBUG("ENTERING");
-	nullfd = open("/dev/null", O_RDWR);
+	nullfd = swbis_devnull_open("/dev/null", O_RDWR, 0);
 	if (!swpath) return -21;
 	if (nullfd < 0) return -22;		
 	if (ifd < 0) return -32;		
@@ -493,7 +493,7 @@ read_catalog_section(void * vp, int ifd)
 			taruib_clear_buffer();
 			swpath_close(swpath);
 			strob_close(namebuf);
-			close(nullfd);
+			swbis_devnull_close(nullfd);
 			return 0;
 		}
 		xformat_get_name(package, namebuf);
@@ -522,7 +522,7 @@ read_catalog_section(void * vp, int ifd)
 			if (copyret < 0) {
 				swpath_close(swpath);
 				strob_close(namebuf);
-				close(nullfd);
+				swbis_devnull_close(nullfd);
 				return copyret;
 			}
 			taruib_set_fd(nullfd);
@@ -531,14 +531,14 @@ read_catalog_section(void * vp, int ifd)
 			taruib_clear_buffer();
 			swpath_close(swpath);
 			strob_close(namebuf);
-			close(nullfd);
+			swbis_devnull_close(nullfd);
 			return 0;
 		}
 	}
 	taruib_clear_buffer();
 	swpath_close(swpath);
 	strob_close(namebuf);
-	close(nullfd);
+	swbis_devnull_close(nullfd);
 	return 1;
 }
 
@@ -555,7 +555,7 @@ taruib_write_signedfile_if_i(void * vp, int ofd,
 {
 	XFORMAT * package = (XFORMAT *)vp;
 	int i;
-	int nullfd = open("/dev/null", O_RDWR);
+	int nullfd = swbis_devnull_open("/dev/null", O_RDWR, 0);
 	int memfd = -1;
 	int ifd = xformat_get_ifd(package);
 	int passfd;
@@ -614,7 +614,7 @@ taruib_write_signedfile_if_i(void * vp, int ofd,
 			break;
 
 			/*
-			close(nullfd);
+			swbis_devnull_close(nullfd);
 			swpath_close(swpath);
 			strob_close(oldnamebuf);
 			strob_close(namebuf);
@@ -773,7 +773,7 @@ taruib_write_signedfile_if_i(void * vp, int ofd,
 				swpath_close(swpath);
 				strob_close(oldnamebuf);
 				strob_close(namebuf);
-				close(nullfd);
+				swbis_devnull_close(nullfd);
 				return -8;
 			}
 			E_DEBUG3("copyret = %d for %s", copyret, name);
@@ -807,7 +807,7 @@ taruib_write_signedfile_if_i(void * vp, int ofd,
 	strob_close(oldnamebuf);
 	strob_close(namebuf);
 	swpath_close(swpath);
-	close(nullfd);
+	swbis_devnull_close(nullfd);
 	if (got_sha1 && !got_md5) {
 		/* anomaly, disallow it */
 		return -9;
