@@ -224,9 +224,10 @@ table_find(int uxfio_fildes, UXFIO ** uxfio_addr, int v)
 		}
 	}
 	*uxfio_addr = (void *) (NULL);
+	if (uxfio_fildes == -1) return -1;
+
 	UXFIO_E_DEBUG2("error %d", uxfio_fildes);
-	if (v) fprintf(stderr,
-		"uxfio error: descriptor %d not found.\n", uxfio_fildes);
+	if (v) fprintf(stderr, "uxfio error [%d]: descriptor %d not found.\n", __LINE__, uxfio_fildes);
 	return -1;
 }
 
@@ -691,7 +692,7 @@ uxfio_common_read(UXFIO *uxfio, int uxfio_fildes, void *buf,
 		if (table_find(uxfio_fildes, &uxfio, 1)) {
 			UXFIO_E_DEBUG2("error %d", uxfio_fildes);
 			fprintf(stderr,
-		"uxfio error: uxfio_common_read: file desc %d not found.\n",
+		"uxfio error [%d]: uxfio_common_read: file desc %d not found.\n", __LINE__,
 						uxfio_fildes);
 			UXFIO_E_DEBUG("LEAVING");
 			return -1;
@@ -1190,7 +1191,7 @@ uxfio_internal_ftruncate(int uxfio_fildes, off_t nbyte)
 	if (table_find(uxfio_fildes, &uxfio, 1)) {
 		UXFIO_E_DEBUG("error");
 		fprintf(stderr,
-			"uxfio error:  file desc %d not found.\n",
+			"uxfio error [%d]:  file desc %d not found.\n", __LINE__,
 					uxfio_fildes);
 		return -1;
 	}
@@ -1458,7 +1459,7 @@ uxfio_debug_get_object_address(int uxfiofd)
 	UXFIO_E_DEBUG("");
 	if (table_find(uxfiofd, &uxfio, 1)) {
 		UXFIO_E_DEBUG("error");
-		fprintf(stderr, "uxfio error:  file desc %d not found.\n",
+		fprintf(stderr, "uxfio error [%d]:  file desc %d not found.\n", __LINE__,
 				uxfiofd);
 		return (UXFIO*)NULL;
 	}
@@ -1542,7 +1543,7 @@ uxfio_opendup(int uxfd, int buffertype)
 	
 	if (table_find(uxfio_fd, &uxfio, 1)) {
 		UXFIO_E_DEBUG("error");
-		fprintf(stderr, "uxfio error: file desc  %d not found.\n",
+		fprintf(stderr, "uxfio error [%d]: file desc %d not found.\n", __LINE__,
 			uxfio_fd);
 		return -1;
 	}
@@ -1789,7 +1790,7 @@ uxfio_write(int uxfio_fildes, void *buf, size_t nbyte)
 		if (table_find(uxfio_fildes, &uxfio, 1)) {
 			UXFIO_E_DEBUG("error");
 			fprintf(stderr,
-				"uxfio error:  file desc %d not found.\n",
+				"uxfio error [%d]:  file desc %d not found.\n", __LINE__,
 					uxfio_fildes);
 			return -1;
 		}
@@ -1910,7 +1911,7 @@ uxfio_lseek(int uxfio_fildes, off_t poffset, int pwhence)
 	}
 	if (table_find(uxfio_fildes, &uxfio, 1)) {
 		UXFIO_E_DEBUG("error");
-		fprintf(stderr, "uxfio error: file desc %d not found.\n",
+		fprintf(stderr, "uxfio error [%d]: file desc %d not found.\n", __LINE__,
 			uxfio_fildes);
 		return -1;
 	}
@@ -2276,7 +2277,7 @@ uxfio_fsync(int uxfio_fildes)
 	if (table_find(uxfio_fildes, &uxfio, 1)) {
 		UXFIO_E_DEBUG("error");
 		fprintf(stderr,
-			"uxfio error: file desc %d not found.\n",
+			"uxfio error [%d]: file desc %d not found.\n", __LINE__,
 				uxfio_fildes);
 		return -1;
 	}
@@ -2300,8 +2301,7 @@ uxfio_ioctl(int uxfio_fd, int request, void * arg)
 	UXFIO_E_DEBUG2("uxfio_filedes=%d", uxfio_fd);
 	if (table_find(uxfio_fd, &uxfio, 1)) {
 		UXFIO_E_DEBUG("error");
-		fprintf(stderr, "uxfio error: file desc %d not found.\n",
-				uxfio_fd);
+		fprintf(stderr, "uxfio error [%d]: file desc %d not found.\n", __LINE__, uxfio_fd);
 		return -1;
 	}
 	if (request == UXFIO_IOCTL_SET_STATBUF) {
@@ -2337,8 +2337,7 @@ uxfio_fstat(int uxfio_fd, struct stat * buf)
 	UXFIO_E_DEBUG2("uxfio_filedes=%d", uxfio_fd);
 	if (table_find(uxfio_fd, &uxfio, 1)) {
 		UXFIO_E_DEBUG("error");
-		fprintf(stderr, "uxfio error: file desc %d not found.\n",
-						uxfio_fd);
+		fprintf(stderr, "uxfio error [%d]: file desc %d not found.\n", __LINE__, uxfio_fd);
 		return -1;
 	}
 	if (uxfio->statbufM == NULL)
@@ -2361,8 +2360,7 @@ uxfio_fcntl(int uxfio_fildes, int cmd, int value)
 	}	
 	if (table_find(uxfio_fildes, &uxfio, 1)) {
 		UXFIO_E_DEBUG("error");
-		fprintf(stderr, "uxfio error: file desc %d not found.\n",
-						uxfio_fildes);
+		fprintf(stderr, "uxfio error [%d]: file desc %d not found.\n", __LINE__, uxfio_fildes);
 		return -1;
 	}
 	
@@ -2639,8 +2637,7 @@ uxfio_get_dynamic_buffer(int uxfio_fildes, char **buffer_ptr,
 
 	if (table_find(uxfio_fildes, &uxfio, 1)) {
 		UXFIO_E_DEBUG("error");
-		fprintf(stderr, "uxfio error: file desc %d not found.\n",
-					uxfio_fildes);
+		fprintf(stderr, "uxfio error [%d]: file desc %d not found.\n", __LINE__, uxfio_fildes);
 		return -1;
 	}
 	if (uxfio->buffertypeM == UXFIO_BUFTYPE_DYNAMIC_MEM) {
