@@ -22,6 +22,7 @@
 
 
 #include "swuser_config.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -35,7 +36,7 @@
 #include <string>
 
 #include <typeinfo>
-#include "stream_config.h"
+#include "xstream_config.h"
 #include "usgetopt.h"
 #include "swstruct.h"
 #include "swstruct_i.h"
