@@ -16,7 +16,7 @@
 #include <string>
 
 #include <typeinfo>
-#include "stream_config.h"
+#include "xstream_config.h"
 #include "swparser.h"
 #include "swattribute.h"
 #include "swdefinition.h"
@@ -140,7 +140,7 @@ main(int argc, char **argv)
 		       "M: j. write using swheader 	k. peek at next line. 		l. get next line.\n"
 		       "M: m. get current line. 					n. Set swheader offset.	\n"
 		       "M: o. insert attribute in swdefinition  			p. make version id.\n"
-		       "M: q. find attribute using swheader_get_attribute_in_object().  r. get next object.\n"
+		       "M: q. find attribute using swheader_get_attribute_in_current_object().  r. get next object.\n"
 		       "M: z. debug dump.\n"
 		       );
 		
@@ -434,7 +434,7 @@ main(int argc, char **argv)
 			
 			fprintf(stdout,"find keyword in current object swm=%p\n", (void*)swm);
 			fprintf(stdout,"enter keyword: <%s> ", keyword); get_string(keyword);
-			obj=swheader_get_attribute(swheader, keyword);
+			obj=swheader_get_attribute(swheader, keyword, NULL);
 			if (!obj) {
 				fprintf(stderr, "not found.\n");
 			} else {
@@ -538,11 +538,11 @@ main(int argc, char **argv)
 			} else {
 				int is_multi_value = 0;
 				fprintf(stdout,"enter keyword: "); get_string(keyword);
-				line = swheader_get_attribute_in_object(swheader,  keyword, object_keyword, &is_multi_value);
+				line = swheader_get_attribute_in_current_object(swheader,  keyword, object_keyword, &is_multi_value);
 				fprintf(stdout, "is_multi_value = [%d]\n", is_multi_value);
 				while (line) {
 					swheaderline_write_debug(line, STDOUT_FILENO);
-					line = swheader_get_attribute_in_object(swheader, keyword, object_keyword, &is_multi_value);
+					line = swheader_get_attribute_in_current_object(swheader, keyword, object_keyword, &is_multi_value);
 				}
 			}
 			break;
